pub enum SegmentArchiverTaskError {
Instantiation {
error: ArchiverInstantiationError,
},
PersistSegmentHeaders {
error: PersistSegmentHeadersError,
},
ArchivingReorg {
parent_block_root: BlockRoot,
best_archived_block_root: BlockRoot,
},
BlockGap {
best_archived_block_number: BlockNumber,
block_number_to_archive: BlockNumber,
importing_block_number: BlockNumber,
},
}Expand description
Segment archiver task error
Variants
Instantiation
Archiver instantiation error
Fields

error: ArchiverInstantiationErrorLow-level error
PersistSegmentHeaders
Failed to persist a new segment header
Fields

error: PersistSegmentHeadersErrorLow-level error
ArchivingReorg
Attempt to switch to a different fork beyond archiving depth
Fields

parent_block_root: BlockRootParent block root

best_archived_block_root: BlockRootBest archived block root
BlockGap
There was a gap in blockchain history, and the last contiguous series of blocks doesn’t start with the archived segment